SWDEV-327563 - Enable fixed tests linux and windows (#2803)
Change-Id: Icad90d01f796a8a8cf57884b86ca1a5a2b50ec64
This commit is contained in:
committed by
GitHub
parent
e3ee2626f4
commit
1458912363
@@ -65,10 +65,6 @@ TEST_CASE("Unit_hipHostUnregister_MemoryNotAccessableAfterUnregister") {
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipHostUnregister_NullPtr") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-90");
|
||||
return;
|
||||
#endif
|
||||
HIP_CHECK_ERROR(hipHostUnregister(nullptr), hipErrorInvalidValue);
|
||||
}
|
||||
|
||||
|
||||
@@ -494,10 +494,6 @@ TEMPLATE_TEST_CASE("Unit_hipMallocArray_MaxTexture_Default", "", uint, int4, ush
|
||||
|
||||
// Arrays with channels of different size are not allowed.
|
||||
TEST_CASE("Unit_hipMallocArray_Negative_DifferentChannelSizes") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-129");
|
||||
return;
|
||||
#endif
|
||||
const int bitsX = GENERATE(8, 16, 32);
|
||||
const int bitsY = GENERATE(8, 16, 32);
|
||||
const int bitsZ = GENERATE(8, 16, 32);
|
||||
|
||||
@@ -71,9 +71,6 @@ TEST_CASE("Unit_hipMemset_Negative_InvalidPtr") {
|
||||
|
||||
|
||||
TEST_CASE("Unit_hipMemset_Negative_OutOfBoundsSize") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-20");
|
||||
#endif
|
||||
|
||||
#if !HT_AMD
|
||||
void* dst;
|
||||
@@ -112,10 +109,6 @@ TEST_CASE("Unit_hipMemset2D_Negative_InvalidPtr") {
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipMemset2D_Negative_InvalidSizes") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-52");
|
||||
#endif
|
||||
|
||||
void* dst;
|
||||
size_t realPitch;
|
||||
HIP_CHECK(hipMallocPitch(&dst, &realPitch, width, height));
|
||||
@@ -181,10 +174,6 @@ TEST_CASE("Unit_hipMemset3D_Negative_ModifiedPtr") {
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipMemset3D_Negative_InvalidSizes") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-52");
|
||||
#endif
|
||||
|
||||
hipPitchedPtr pitchedDevPtr;
|
||||
HIP_CHECK(hipMalloc3D(&pitchedDevPtr, validExtent));
|
||||
hipExtent invalidExtent{validExtent};
|
||||
|
||||
Reference in New Issue
Block a user